/****************************************************************************
*    Filename:     CCU40.c
*    IDE:          DAVE_3.1.6
*    MCU:          XMC13OO
*
*    Revision History:
*    -------------------------------------------------------------------------
*    V1.0       2013-8-13    Created
*
*    Support :  IFCN.MCU@Infineon.com
*
*    Copyright (c) Infineon Semiconductor 2012. All Rights Reserved.
*****************************************************************************/


/*****************************************************************************
 *    Include Files
 *****************************************************************************/
#include <XMC1300.h>
#include "CCU40.h"

/*****************************************************************************
*     Macro Definitions
*****************************************************************************/


/*****************************************************************************
*     Local Type Definitions
*****************************************************************************/


/*****************************************************************************
*     Static(Local) Variable Definitions
*****************************************************************************/

/*****************************************************************************
*     Local Function Declarations
*****************************************************************************/


/*****************************************************************************
*     Global Variable Definitions
*****************************************************************************/
uint64_t Per_Val =0x14FFFF;			  //ֵ趨  48λ
uint64_t Com_Val=0x00083FFF;          //Ƚֵ趨  48λ
/*****************************************************************************
 *    Global Function Definitions
 *****************************************************************************/


/*****************************************************************************
*     Variable setting for testing, delete it when release
*****************************************************************************/


/*****************************************************************************
 * Function:      void  CCU40_vInit(void)
 * Description:   Initialize the CCU40 Module
 *                (ʼCCU40,Ƶֵʹ012ƬΪ48λʱ)
 * Caveats:       2013-8-13
 *                test only (ʱӼ)
 *****************************************************************************/
void CCU40_vInit(void)
{

	//-------------------------------------------------------------------------
	// Step 1:  λֹ
	//          PASSWD ---RMv1.0 Page326
	//-------------------------------------------------------------------------
	SCU_GENERAL->PASSWD = 0x000000C0UL;
	//-------------------------------------------------------------------------
	// Step 2:  ֹͣCCU40
	//          CGATCLR0 ---RMv1.0 Page304
	//-------------------------------------------------------------------------
	SCU_CLK->CGATCLR0 = 0x00000004UL;
	//-------------------------------------------------------------------------
	// Step 3:  8 MHz MCLK, 8 MHz PCLK
	//          CLKCR ---RMv1.0 Page298
	//-------------------------------------------------------------------------
	SCU_CLK->CLKCR = 0x3FF00400UL;
	//-------------------------------------------------------------------------
	// Step 4:  ʹλ00Ϊ11ʹܱ
	//          PASSWD ---RMv1.0 Page326
	//-------------------------------------------------------------------------
	SCU_GENERAL->PASSWD = 0x000000C3UL;
	//-------------------------------------------------------------------------
	// Step 5: λƵλ
	//         GIDLC ---RMv1.0 Page839
	//-------------------------------------------------------------------------
	CCU40->GIDLC |= 0x00000100;
	//-------------------------------------------------------------------------
	// Step 6: Ƭ012÷ƵCCU4/32
	//         PSC ---RMv1.0 Page863
	//-------------------------------------------------------------------------
	CCU40_CC40->PSC|=0x00000005;
	CCU40_CC41->PSC|=0x00000005;
	CCU40_CC42->PSC|=0x00000005;
	//-------------------------------------------------------------------------
	// Step 7: CCU4Ƭ012ӰڼĴֵ
	//         PRS ---RMv1.0 Page866
	//-------------------------------------------------------------------------
	CCU40_CC40->PRS=Per_Val&0x0000FFFF;
	CCU40_CC41->PRS=(Per_Val>>16)&0x0000FFFF;
	CCU40_CC42->PRS=(Per_Val>>32)&0x0000FFFF;
	//-------------------------------------------------------------------------
	// Step 8: CCU4Ƭ012ӰӱȽϼĴֵ
	//         CRS ---RMv1.0 Page868
	//-------------------------------------------------------------------------
	CCU40_CC40->CRS=Com_Val&0x0000FFFF;
	CCU40_CC41->CRS=(Com_Val>>16)&0x0000FFFF;
	CCU40_CC42->CRS=(Com_Val>>32)&0x0000FFFF;
	//-------------------------------------------------------------------------
	// Step 9: ʹCCU4012ƥʱӰӼĴֵ
	//         GCSS ---RMv1.0 Page840
	//-------------------------------------------------------------------------
	CCU40->GCSS|=0x00000001;                   //ʹӰֵ
	CCU40->GCSS|=0x00000010;                   //ʹӰֵ
	CCU40->GCSS|=0x00000100;                   //ʹӰֵ
	//-------------------------------------------------------------------------
	// Step 10: CCU4Ƭ12еʱӼʹܣγ48λʱ
	//          CMC ---RMv1.0 Page850
	//-------------------------------------------------------------------------
	CCU40_CC41->CMC=0x00100000;
	CCU40_CC42->CMC=0x00100000;
	//-------------------------------------------------------------------------
	// Step 11: CCU4Ƭ012λ
	//          GIDLC ---RMv1.0 Page839
	//-------------------------------------------------------------------------
	CCU40->GIDLC |= 0x00000007;
	//-------------------------------------------------------------------------
	// Step 12: ʹCCU4Ƭ012ƥҼж
	//          INTE ---RMv1.0 Page875
	//-------------------------------------------------------------------------
	CCU40_CC40->INTE|= 0x00000001;
	CCU40_CC41->INTE|= 0x00000001;
	CCU40_CC42->INTE|= 0x00000001;
	//-------------------------------------------------------------------------
	// Step 13: CCU4Ƭ012ƥ󴫵ݵ CC4ySR0
	//          SRS ---RMv1.0 Page 877
	//-------------------------------------------------------------------------
	CCU40_CC40->SRS|= 0x00000000;
	CCU40_CC41->SRS|= 0x00000000;
	CCU40_CC42->SRS|= 0x00000000;
	//-------------------------------------------------------------------------
	// Step 14: P0.0Ϊͨź˿
	//          IOCR0 ---RMv1.0 Page1205
	//-------------------------------------------------------------------------
	P0_0_set_mode(OUTPUT_PP_GP);
	//-------------------------------------------------------------------------
	// Step 15: ڵĵȴ״̬
	//          ICPR---RMv1.0 Page112
	//-------------------------------------------------------------------------
	NVIC_ClearPendingIRQ(CCU40_0_IRQn);
	//-------------------------------------------------------------------------
	// Step 16: ʹܽڵж
	//          ISER---RMv1.0 Page109
	//-------------------------------------------------------------------------
	NVIC_EnableIRQ(CCU40_0_IRQn);
	//-------------------------------------------------------------------------
	// Step 17: CCU4Ƭ012ʱ
	//          TCSET ---RMv1.0 Page 854
	//-------------------------------------------------------------------------
	CCU40_CC40->TCSET=0x00000001;
	CCU40_CC41->TCSET=0x00000001;
	CCU40_CC42->TCSET=0x00000001;
}

/*****************************************************************************
 * Function:      void CCU40_0_IRQHandler(void)
 * Description:   CCU4Ƭ012ʱƥжϷ
 *                ʵ趨ֵƥ䣬P0.0ƽת
 * Caveats:       2013-8-13
 *
 *****************************************************************************/
void CCU40_0_IRQHandler(void)
{

    //-------------------------------------------------------------------------
    // Step 1: CCU4Ƭ0ƥжϴ
	//         INTS ---RMv1.0 Page873
	//         SWR  ---RMv1.0 Page880
	//         PRS  ---RMv1.0 Page866
	//         CRS  ---RMv1.0 Page868
    //-------------------------------------------------------------------------

	if((CCU40_CC40->INTS&0x01)==1)                 //жCCU4Ƭ0Ƿƥж
	{
		CCU40_CC40->SWR=0X00000005;                //ƥжϱ
	    CCU40_CC40->PRS=Per_Val&0x0000FFFF;        //дֵӰڼĴ
	    CCU40_CC40->CRS=Com_Val&0x0000FFFF;        //дֵӰӱȽϼĴ
	    if ((Per_Val>>16)==0)                      //ж趨ֵǷСCCU4Ƭ0ֵ
		    P0_0_toggle();                         //P0.0ƽת
	}
    //-------------------------------------------------------------------------
    // Step 2: CCU4Ƭ1ƥжϴ
	//         INTS ---RMv1.0 Page873
	//         SWR  ---RMv1.0 Page880
	//         PRS  ---RMv1.0 Page866
	//         CRS  ---RMv1.0 Page868
    //-------------------------------------------------------------------------

	if((CCU40_CC41->INTS&0x01)==1)                 //жCCU4Ƭ1Ƿƥж
	{
		CCU40_CC41->SWR=0X00000005;                //ƥжϱ
	    CCU40_CC41->PRS=(Per_Val>>16)&0x0000FFFF;  //дֵӰڼĴ
	    CCU40_CC41->CRS=(Com_Val>>16)&0x0000FFFF;  //дֵӰӱȽϼĴ
	    if ((Per_Val>>32)==0)                      //ж趨ֵǷСCCU4Ƭ1ֵ
		    P0_0_toggle();                         //P0.0ƽת
	}

    //-------------------------------------------------------------------------
    // Step 3: CCU4Ƭ2ƥжϴ
	//         INTS ---RMv1.0 Page873
	//         SWR  ---RMv1.0 Page880
	//         PRS  ---RMv1.0 Page866
	//         CRS  ---RMv1.0 Page868
    //-------------------------------------------------------------------------

	if((CCU40_CC42->INTS&0x01)==1)                 //жCCU4Ƭ2Ƿƥж
	{
		CCU40_CC42->SWR=0X00000005;                //ƥжϱ
		CCU40_CC42->PRS=(Per_Val>>32)&0x0000FFFF;  //дֵӰڼĴ
		CCU40_CC42->CRS=(Com_Val>>32)&0x0000FFFF;  //дֵӰӱȽϼĴ

	}
}

